@@ -8,6 +8,11 @@ import html
 
 global_chars_lang = {}
 
+chars3Re = regex.compile("[\uE000-\uFFFF]")
+chars3Re2 = regex.compile("[\u2000-\u200F]")
+chars3Re3 = regex.compile("\u007F|[\u0080-\u00A0]")
+quotesRegex = regex.compile("(?P<start>[[:alpha:]])\'\'(?P<end>(s|S|t|T|m|M|d|D|re|RE|ll|LL|ve|VE|em|EM)\W)")
+collapse_spaced_entities = regex.compile('([&][ ]*[#][ ]*)([0-9]{2,6})([ ]*[;])')
 
 def getCharsReplacements(lang):
     # languages that use cyrillic alphabet
@@ -61,7 +66,10 @@ def getCharsReplacements(lang):
     # Annoying characters, common for all languages
     chars = {
         '\u2028': ' ',  # line separators (\n)
-        '&#10;': "",  # \n
+        '&#10;': " ",  # \n
+        '&#9;': " ",  # \t
+        '&#10': " ",  # \n
+        '&#9': " ",  # \t
         '\n': "",
         '\u000C' : " ", # \v vertical tab
         '\u000D' : " ", # \f form feed
@@ -206,6 +214,10 @@ def getCharsReplacements(lang):
         'Ã<87>': 'Ç',
         'Ã‡': 'Ç',
         'Ã§': 'ç',
+        'ÄŤ': 'č',
+        'ДЌ': 'č',
+        'Д‡': 'ć',
+        "ÄŚ": "Č",
 
         'Ã<88>': 'È',
         'Ã<89>': 'É',
@@ -224,7 +236,7 @@ def getCharsReplacements(lang):
         'Ã<8C>': 'Ì',
         'Ã<8E>': 'Î',
         'ÃŒ': 'Ì',
-        'Ã<8D>': 'Í',
+        #'Ã<8D>': 'Í',
         'ÃŽ': 'Î',
         'Ã<8F>': 'Ï',
         'Ã¬': 'ì',
@@ -261,6 +273,11 @@ def getCharsReplacements(lang):
         'Ã±': 'ñ',
 
         'Å¡': 'š',
+        'ĹĄ': 'š',
+        'ЕЎ': 'š',
+        "Ĺˇ": "š",
+        "Å¡": "š",
+        "Ĺ ": "Š",
 
         'Å¥': 'ť',
 
@@ -285,6 +302,11 @@ def getCharsReplacements(lang):
         'Ã¿': 'ÿ',
         'Å½': 'Ž',
         'Å¾': 'ž',
+        'Ĺľ': 'ž',
+        'Ĺˇ': 'ž',
+        'Ĺž': 'ž',
+        "Ĺ˝": "Ž",
+        "Å3⁄4": "ž",
 
         'Ãž': 'Þ',
         'Ã<9E>': 'Þ',
@@ -294,7 +316,7 @@ def getCharsReplacements(lang):
         'ÃŸ': 'ß',
         'Ã<9F>': 'ß',
         'Âµ': 'µ',
-        'Ã°': 'ð'
+        'Ã°': 'ð',
 
     }
 
@@ -639,8 +661,13 @@ def getNormalizedPunctReplacements(lang):
             "{ ": "{",
             "[ ": "[",
             "¿ ": "¿",
+            ",,.": ".",
             "¡ ": "¡"
         }
+    if lang.lower() == 'sl':
+        del replacements[' ...']
+        del replacements[' :']
+
     rep = dict((re.escape(k), v) for k, v in replacements.items())
     pattern = re.compile("|".join(rep.keys()))
     return rep, pattern
@@ -687,36 +714,18 @@ def replace_chars3(match):
     return ""
 
 
-def fix(text, lang, chars_rep, chars_pattern, punct_rep, punct_pattern):
+def fix(text, lang, chars_rep, chars_pattern):
     global global_chars_lang
     global_chars_lang = chars_rep
 
-    # htmlEntity=regex.compile(r'[&][[:space:]]*[#][[:space:]]*[0-9]{2,4}[[:space:]]*[;]?',regex.U)
-    chars3Re = regex.compile("[\uE000-\uFFFF]")
-    chars3Re2 = regex.compile("[\u2000-\u200F]")
-    chars3Re3 = regex.compile("\u007F|[\u0080-\u00A0]")
-    quotesRegex = regex.compile("(?P<start>[[:alpha:]])\'\'(?P<end>(s|S|t|T|m|M|d|D|re|RE|ll|LL|ve|VE|em|EM)\W)")
-    collapse_spaced_entities = regex.compile('([&][ ]*[#][ ]*)([0-9]{2,6})([ ]*[;])')
+    ftfy_fixed_text = ftfy.fix_text_segment(text, uncurl_quotes=False, fix_latin_ligatures=False)
 
-    # Test encode: fix mojibake
-    ftfy_fixed_text = " ".join([ftfy.fix_text_segment(word, uncurl_quotes=False, fix_latin_ligatures=False) for word in text.split()])
-    # ftfy_fixed_text= ftfy.fix_text_segment(stripped_text, fix_entities=True,uncurl_quotes=False,fix_latin_ligatures=False)
+    replaced_text = chars_pattern.sub(replace_chars, ftfy_fixed_text)
 
-    # nicely_encoded_text = htmlEntity.sub(html.unescape, nicely_encoded_text)
-    nicely_encoded_text = html.unescape(ftfy_fixed_text)
-
-    # First replacing all HTML entities
-    # for substring in htmlEntity.findall(nicely_encoded_text):
-    #    code=substring.replace(' ','')[2:].replace(';','')
-    #    try:
-    #        newChar=chr(int(code))
-    #    except ValueError:
-    #        newChar=code    
-    #    if newChar != "\n":
-    #        nicely_encoded_text = nicely_encoded_text.replace(substring,newChar)
-
-    normalized_text = chars_pattern.sub(replace_chars, nicely_encoded_text)
+    return html.unescape(replaced_text)
 
+def normalize(text, lang, punct_rep, punct_pattern):
+    normalized_text = text
     if lang.lower() != "ja":
         normalized_text = chars3Re.sub(replace_chars3, normalized_text)
     normalized_text = chars3Re2.sub(replace_chars3, normalized_text)
